require '/home/user/work/ruby/MesaScript/mesa_script/lib/mesa_script.rb'

masses = (0...28).map{|i| 1.0 + i*0.2 }
puts masses

masses.each do |mass|
  mass_string = sprintf("%.2f",mass)
  logfile = "logfile" + mass_string + ".txt"
  pngname = "png_Mi_"+mass_string

  Inlist.make_inlist('inlist_common') do
  
  # &star_job
        show_log_description_at_start false  
        
        change_net true      
        new_net_name 'co_burn_extras.net'
        
        set_initial_age false
        set_initial_model_number false
  
        num_special_rate_factors 2
        reaction_for_special_factor[1] = 'r_c12_ag_o16'
        special_rate_factor[1] = 1
        filename_of_special_rate[1] = 'r_c12_ag_o16_kunz.txt'
  
        reaction_for_special_factor[2] = 'r_he4_he4_he4_to_c12'
        special_rate_factor[2] = 1
        filename_of_special_rate[2] = 'r_he4_he4_he4_to_c12_cf88.txt'
  
  # / ! end of star_job namelist
  
  # &controls
  
        initial_mass mass
  
        initial_z 0.02e0
        
  # opacity
  
  # when to stop
        max_age 14e9
  
  # mesh
        mesh_delta_coeff 1.5
  
  # diffusion
        #do_element_diffusion = .true.    
        #do_WD_sedimentation_heating = .true. 
        #do_diffusion_heating = .false.
  
        #show_diffusion_info = .true. ! terminal output for diffusion
  
        diffusion_v_max 1e-5
        
        # Bypasses the need to set up diffusion classes.
        diffusion_use_full_net true
  
        # Solver controls.
        diffusion_use_cgs_solver true
        diffusion_use_isolve true
        diffusion_rtol_for_isolve 1e-4
        diffusion_atol_for_isolve 1e-5
        diffusion_min_x_hard_limit -1e-4
        diffusion_maxsteps_for_isolve 1000
        diffusion_isolve_solver 'ros2_solver'
  
        # Timestep controls to prevent steps that are difficult for diffusion.
        diffusion_steps_limit 20
        diffusion_steps_hard_limit 50
        diffusion_iters_limit 50
        diffusion_iters_hard_limit 100      
  
  # convection
        mlt_option 'TDC'
        mixing_length_alpha 2
        use_ledoux_criterion true
        thermohaline_coeff 1e2
  
  # timesteps
        max_years_for_timestep 1e9
        
        varcontrol_target 1e-3
        dx_nuc_drop_limit 3e-2
        delta_hr_limit 0.1
  
        delta_xc_cntr_limit 0.02e0
        delta_xo_cntr_limit 0.02e0
        delta_xc_cntr_hard_limit 0.05e0
        delta_xo_cntr_hard_limit 0.05e0
  
  # Atm
        atm_option 'T_tau'
        atm_t_tau_relation 'Eddington'
        atm_t_tau_opacity 'iterated'
        atm_t_tau_max_iters 100
  
  # Overshoot
        overshoot_scheme[1] = 'exponential'
        overshoot_zone_type[1] = 'any'
        overshoot_zone_loc[1] = 'any'
        overshoot_bdy_loc[1] = 'any'
        overshoot_f[1] = 0.014
        overshoot_f0[1] = 0.004
  
  # Output
        history_interval 10
        terminal_interval 10 
        write_header_frequency 10
  
  
  # / ! end of controls namelist
  
  
  
  # &pgstar
  
        grid2_win_width 10
        grid2_win_aspect_ratio 0.7 # aspect_ratio = height/width
        #Grid2_plot_name(2) = 'Power'
        #Power_xmin = 0.510 ! only used if /= -101d0
        #Power_xmax = 0.590 ! only used if /= -101d0
           
        grid2_file_flag true
        grid2_file_width 15
        grid2_file_dir pngname
        grid2_file_interval 10 # output when mod(model_number,Grid2_file_interval)==0
        grid2_file_aspect_ratio -1 # negative means use same value as for window
  
  
           grid2_num_plots 5 # <= 10
  
           grid2_plot_name[1] = 'TRho_Profile'
           grid2_plot_row[1] = 1 # number from 1 at top
           grid2_plot_rowspan[1] = 3 # plot spans this number of rows
           grid2_plot_col[1] = 1 # number from 1 at left
           grid2_plot_colspan[1] = 2 # plot spans this number of columns
           grid2_plot_pad_left[1] = 0.0 # fraction of full window width for padding on left
           grid2_plot_pad_right[1] = 0.0 # fraction of full window width for padding on right
           grid2_plot_pad_top[1] = 0.0 # fraction of full window height for padding at top
           grid2_plot_pad_bot[1] = 0.1 # fraction of full window height for padding at bottom
           grid2_txt_scale_factor[1] = 0.7 # multiply txt_scale for subplot by this
  
           grid2_plot_name[2] = 'HR'
           grid2_plot_row[2] = 4 # number from 1 at top
           grid2_plot_rowspan[2] = 3 # plot spans this number of rows
           grid2_plot_col[2] = 1 # number from 1 at left
           grid2_plot_colspan[2] = 1 # plot spans this number of columns
           grid2_plot_pad_left[2] = 0.00 # fraction of full window width for padding on left
           grid2_plot_pad_right[2] = 0.04 # fraction of full window width for padding on right
           grid2_plot_pad_top[2] = 0.03 # fraction of full window height for padding at top
           grid2_plot_pad_bot[2] = 0.0 # fraction of full window height for padding at bottom
           grid2_txt_scale_factor[2] = 0.65 # multiply txt_scale for subplot by this
  
           grid2_plot_name[3] = 'TRho'
           grid2_plot_row[3] = 4 # number from 1 at top
           grid2_plot_rowspan[3] = 3 # plot spans this number of rows
           grid2_plot_col[3] = 2 # number from 1 at left
           grid2_plot_colspan[3] = 1 # plot spans this number of columns
           grid2_plot_pad_left[3] = 0.04 # fraction of full window width for padding on left
           grid2_plot_pad_right[3] = 0.00 # fraction of full window width for padding on right
           grid2_plot_pad_top[3] = 0.03 # fraction of full window height for padding at top
           grid2_plot_pad_bot[3] = 0.0 # fraction of full window height for padding at bottom
           grid2_txt_scale_factor[3] = 0.65 # multiply txt_scale for subplot by this
  
           grid2_plot_name[4] = 'Text_Summary1'
           grid2_plot_row[4] = 7 # number from 1 at top
           grid2_plot_rowspan[4] = 2 # plot spans this number of rows
           grid2_plot_col[4] = 1 # number from 1 at left
           grid2_plot_colspan[4] = 4 # plot spans this number of columns
           grid2_plot_pad_left[4] = -0.08 # fraction of full window width for padding on left
           grid2_plot_pad_right[4] = 0.0 # fraction of full window width for padding on right
           grid2_plot_pad_top[4] = 0.08 # fraction of full window height for padding at top
           grid2_plot_pad_bot[4] = -0.04 # fraction of full window height for padding at bottom
           grid2_txt_scale_factor[4] = 0.19 # multiply txt_scale for subplot by this
  
           grid2_plot_name[5] = 'Profile_Panels3'
           grid2_plot_row[5] = 1 # number from 1 at top
           grid2_plot_rowspan[5] = 6 # plot spans this number of rows
           grid2_plot_col[5] = 3 # number from 1 at left
           grid2_plot_colspan[5] = 2 # plot spans this number of columns
           grid2_plot_pad_left[5] = 0.15 # fraction of full window width for padding on left
           grid2_plot_pad_right[5] = 0.03 # fraction of full window width for padding on right
           grid2_plot_pad_top[5] = 0.0 # fraction of full window height for padding at top
           grid2_plot_pad_bot[5] = 0.0 # fraction of full window height for padding at bottom
           grid2_txt_scale_factor[5] = 0.65 # multiply txt_scale for subplot by this
  
           profile_panels3_xaxis_name 'mass'
           profile_panels3_xaxis_reversed false
           
           profile_panels3_xmin -101e0 # only used if /= -101d0
           profile_panels3_xmax 2.2 # -101d0 ! only used if /= -101d0
  
  # / ! end of pgstar namelist
  end

  execute_command = './rn | tee ' + logfile
  puts execute_command
  system(execute_command)
  savename = 'WD_Mi_' + mass_string + '.mod'
  save_mod_command = 'mv final.mod ' + savename
  system(save_mod_command)

end
