require '/home/user/work/ruby/MesaScript/mesa_script/lib/mesa_script.rb'

masses = (0...26).map{|i| 0.5 + i*0.02 }
puts masses

masses.each do |mass|
  mass_string = sprintf("%.2f",mass)
  logfile = "logfile_" + mass_string + ".txt"
  logname = 'LOGS_'+mass_string
  pngname = 'png_'+mass_string

  Inlist.make_inlist('inlist_wd_cool') do
  
  
  # &star_job
        relax_mass_scale true
        new_mass mass

        show_log_description_at_start false
  
        load_saved_model true
        load_model_filename '../DAfifty_fifty.mod'
  
        save_model_when_terminate true
        save_model_filename 'final.mod'
        required_termination_code_string 'log_center_temp_lower_limit'
  
        set_initial_age true
        initial_age 0
  
        set_initial_model_number true
        initial_model_number 0  
        set_initial_dt true
        years_for_initial_dt 1e2 # in years
  
        pgstar_flag true
        save_pgstar_files_when_terminate true
  
  # / ! end of star_job namelist
    
  # &controls
        eps_nuc_factor 0e0 # so hydrogen envelope doesn't flash
        
        log_center_temp_lower_limit 5.7e0
        delta_lgt_cntr_limit 3e-3
        delta_lgt_cntr_hard_limit 1e-1
  
        num_trace_history_values 6
        trace_history_value_name[1] = 'total_mass he4'
        trace_history_value_name[2] = 'total_mass c12'
        trace_history_value_name[3] = 'total_mass o16'
        trace_history_value_name[4] = 'total_mass ne22'
        trace_history_value_name[5] = 'rel_E_err'
        trace_history_value_name[6] = 'log_rel_run_E_err'
  
        energy_eqn_option 'eps_grav'
        use_time_centered_eps_grav true
           # since have energy_eqn_option = 'eps_grav'
        limit_for_rel_error_in_energy_conservation 1e-4
        hard_limit_for_rel_error_in_energy_conservation 1e-3
  
        atm_option 'table'
        atm_table 'WD_tau_25'
  
        # Diffusion controls
        do_element_diffusion false
        diffusion_use_full_net true
        do_wd_sedimentation_heating true
        do_diffusion_heating false
  
        mesh_delta_coeff 0.75
        
        when_to_stop_rtol 1e-3
        when_to_stop_atol 1e-3
        
        thermohaline_coeff 1000  
  
        mlt_option 'ML2'
  
        mixing_length_alpha 1.8
  
        log_directory logname
           
        photo_interval 50
        profile_interval 50
        history_interval 1
        terminal_interval 1
        write_header_frequency 10
  
  # / ! end of controls namelist
  
  
  # &pgstar
           
           # Grid2_win_flag = .true.
           grid2_win_width 15
  
           grid2_file_flag true
           grid2_file_width 15
           grid2_file_interval 10
           grid2_file_dir pngname
  
           # TRho_Profile_win_flag = .true.
           show_trho_profile_kap_regions false
           show_trho_profile_eos_regions true
           show_trho_profile_degeneracy_line true
           show_trho_profile_pgas_prad_line true
           show_trho_profile_burn_lines true
           show_trho_profile_burn_labels true
           show_trho_profile_text_info false
  
           # Abundance_win_flag = .true.
           # Abundance_xaxis_name = 'logxm'
           # Abundance_xaxis_reversed = .true.
           # Abundance_xmin = -8
           # Abundance_xmax = 0
           abundance_xaxis_name 'mass'
           abundance_xaxis_reversed false
  
      grid2_plot_name[5] = 'Profile_Panels2'
      profile_panels2_xaxis_name 'radius' # 'mass'
      profile_panels2_xaxis_reversed false
      # Profile_Panels2_xmin = 0
      # Profile_Panels2_xmax = 0.59
  
      profile_panels2_yaxis_name[2] = 'eps_phase_separation'
      profile_panels2_other_yaxis_name[2] = 'gam' 
      profile_panels2_show_mix_regions_on_xaxis true
  
      # / ! end of pgstar namelist
  end

  execute_command = './rn | tee ' + logfile
  puts execute_command
  system(execute_command)

end
  
